@@ -38,10 +38,10 @@ emacspeak modules:
 
 """
 
-__id__ = "$Id: espeechfactory.py 1680 2006-11-09 18:43:48Z wwalker $"
+__id__ = "$Id: espeechfactory.py 2234 2007-04-02 18:36:08Z wwalker $"
 __author__ = "T. V. Raman"
-__version__ = "$Revision: 1680 $"
-__date__ = "$Date: 2006-11-09 13:43:48 -0500 (Thu, 09 Nov 2006) $"
+__version__ = "$Revision: 2234 $"
+__date__ = "$Date: 2007-04-02 14:36:08 -0400 (Mon, 02 Apr 2007) $"
 __copyright__ = "Copyright (c) 2005 Google Inc."
 __license__ = "LGPL"
 __all__=['Speaker']
@@ -91,6 +91,10 @@ class SpeechServer(speechserver.SpeechServer):
 
     def getFactoryName():
         """Returns a localized name describing this factory."""
+        # Translators: this refers to the speech synthesis services
+        # provided by the separate emacspeak utility available at
+        # http://emacspeak.sourceforge.net/.
+        #
         return _("Emacspeak Speech Services")
 
     getFactoryName = staticmethod(getFactoryName)
