@@ -19,9 +19,9 @@
 
 """Custom script for StarOffice and OpenOffice."""
 
-__id__        = "$Id: StarOffice.py 2469 2007-06-12 20:19:09Z richb $"
-__version__   = "$Revision: 2469 $"
-__date__      = "$Date: 2007-06-12 16:19:09 -0400 (Tue, 12 Jun 2007) $"
+__id__        = "$Id: StarOffice.py 2828 2007-09-13 19:26:33Z wwalker $"
+__version__   = "$Revision: 2828 $"
+__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -45,6 +45,7 @@ import orca.keybindings as keybindings
 import orca.where_am_I as where_am_I
 
 from orca.orca_i18n import _ # for gettext support
+from orca.orca_i18n import Q_     # to provide qualified translatable strings
 
 # Whether we speak spread sheet cell coordinates as the user moves around.
 #
@@ -136,7 +137,9 @@ class WhereAmI(where_am_I.WhereAmI):
             # Translators: when the user selects (highlights) text in
             # a document, Orca lets them know this.
             #
-            text = _("selected")
+            # ONLY TRANSLATE THE PART AFTER THE PIPE CHARACTER |
+            #
+            text = Q_("text|selected")
             utterances.append(text)
 
         debug.println(self._debugLevel, "editable table cell utterances=%s" % \
@@ -656,8 +659,12 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
         utterances = []
         if obj.parent.role == rolenames.ROLE_TOOL_BAR:
             if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+                # Translators: this represents the state of a check box
+                #
                 checkedState = _("on")
             else:
+                # Translators: this represents the state of a check box
+                #
                 checkedState = _("off")
 
             utterances.append(obj.name)
@@ -683,8 +690,12 @@ class SpeechGenerator(speechgenerator.SpeechGenerator):
         utterances = []
         if obj.parent.role == rolenames.ROLE_TOOL_BAR:
             if obj.state.count(atspi.Accessibility.STATE_CHECKED):
+                # Translators: this represents the state of a check box
+                #
                 checkedState = _("on")
             else:
+                # Translators: this represents the state of a check box
+                #
                 checkedState = _("off")
 
             utterances.append(obj.name)
@@ -758,7 +769,8 @@ class Script(default.Script):
         # only difference over the default set in settings.py is to add
         # in "left-margin:" and "right-margin:".
 
-        settings.enabledTextAttributes = "size:; family-name:; weight:400; indent:0; left-margin:0; right-margin:0; underline:none; strikethrough:false; justification:left; style:normal;"
+        self.enabledBrailledTextAttributes = "size:; family-name:; weight:400; indent:0mm; left-margin:0mm; right-margin:0mm; underline:none; strikethrough:none; justification:left; style:normal;"
+        self.enabledSpokenTextAttributes = "size:; family-name:; weight:400; indent:0mm; left-margin:0mm; right-margin:0mm; underline:none; strikethrough:none; justification:left; style:normal;"
 
         # [[[TODO: JD - HACK because we won't get events from toggle
         # buttons on the Formatting toolbar until we "tickle/poke"
@@ -772,9 +784,17 @@ class Script(default.Script):
         self.savedreadTableCellRow = settings.readTableCellRow
         settings.readTableCellRow = False
 
+        self.savedEnabledBrailledTextAttributes = settings.enabledBrailledTextAttributes
+        settings.enabledBrailledTextAttributes = self.enabledBrailledTextAttributes
+
+        self.savedEnabledSpokenTextAttributes = settings.enabledSpokenTextAttributes
+        settings.enabledSpokenTextAttributes = self.enabledSpokenTextAttributes
+
     def deactivate(self):
         """Called when this script is deactivated."""
         settings.readTableCellRow = self.savedreadTableCellRow
+        settings.enabledBrailledTextAttributes = self.savedEnabledBrailledTextAttributes
+        settings.enabledSpokenTextAttributes = self.savedEnabledSpokenTextAttributes
 
     def getBrailleGenerator(self):
         """Returns the braille generator for this script.
@@ -1530,7 +1550,7 @@ class Script(default.Script):
         # comment #18 of bug #354463.
         #
         if self.findCommandRun and \
-           event.type == "object:state-changed:focused":
+           event.type.startswith("object:state-changed:focused"):
             self.findCommandRun = False
             self.find()
             return
@@ -1924,7 +1944,7 @@ class Script(default.Script):
         # If this is a state change "focused" event that we care about, and
         # we are in Writer, check to see if we are entering or leaving a table.
         #
-        if event.type == "object:state-changed:focused" and event.detail1 == 1:
+        if event.type.startswith("object:state-changed:focused") and event.detail1 == 1:
             current = event.source.parent
             while current.role != rolenames.ROLE_APPLICATION:
                 # Translators: this is the title of the window that
@@ -1944,7 +1964,7 @@ class Script(default.Script):
         # Prevent  "object:state-changed:active" events from activating
         # the find operation. See comment #18 of bug #354463.
         #
-        if event.type == "object:state-changed:active":
+        if event.type.startswith("object:state-changed:active"):
             if self.findCommandRun:
                 return
 
@@ -1954,13 +1974,15 @@ class Script(default.Script):
             # See bug #363830 and OOo issue #70872.]]]
             #
             if not self.tickled:
-                self.getObjects(self.getFrame(event.source))
-                self.tickled = True
+                frame = self.getFrame(event.source)
+                if frame:
+                    self.getObjects(frame)
+                    self.tickled = True
 
         # Announce when the toolbar buttons are toggled if we just toggled
         # them; not if we navigated to some text.
         #
-        if event.type == "object:state-changed:checked" and \
+        if event.type.startswith("object:state-changed:checked") and \
            (event.source.role == rolenames.ROLE_TOGGLE_BUTTON or \
             event.source.role == rolenames.ROLE_PUSH_BUTTON):
             weToggledIt = False
@@ -1988,7 +2010,7 @@ class Script(default.Script):
         # If we are FOCUSED on a paragraph inside a table cell (in Writer),
         # then speak/braille that parent table cell (see bug #382415).
         #
-        if event.type == "object:state-changed:focused" and \
+        if event.type.startswith("object:state-changed:focused") and \
            event.source.role == rolenames.ROLE_PARAGRAPH and \
            event.source.parent.role == rolenames.ROLE_TABLE_CELL and \
            event.detail1 == 0 and \
@@ -2020,7 +2042,7 @@ class Script(default.Script):
         # instead of focus:). The second is a caret-moved
         # event. Just set the locusOfFocus for the first event.
         #
-        if event.type == "object:state-changed:focused" and \
+        if event.type.startswith("object:state-changed:focused") and \
            event.source.role == rolenames.ROLE_PARAGRAPH and \
            event.source != self.currentParagraph:
             self.currentParagraph = event.source
