@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Custom script for metacity."""
 
-__id__        = "$Id: metacity.py 2126 2007-03-06 21:35:17Z richb $"
-__version__   = "$Revision: 2126 $"
-__date__      = "$Date: 2007-03-06 16:35:17 -0500 (Tue, 06 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: metacity.py 2828 2007-09-13 19:26:33Z wwalker $"
+__version__   = "$Revision: 2828 $"
+__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.braille as braille
@@ -50,45 +50,8 @@ class Script(default.Script):
 
         default.Script.__init__(self, app)
 
-    def onNameChanged(self, event):
-        """The status bar in metacity tells us what toplevel window will be
-        activated when tab is released.  We will key off the name changed
-        event to determine when to say something, as it seems to be the
-        more reliable event.
-
-        Arguments:
-        - event: the name changed Event
-        """
-
-        # Do the default thing if this is not the status bar.
-        #
-        if event.source.role != rolenames.ROLE_STATUSBAR:
-            default.Script.onNameChanged(self, event)
-
-    def onStateChanged(self, event):
-        """The status bar in metacity tells us what toplevel window will be
-        activated when tab is released.
-
-        Arguments:
-        - event: the object:state-changed: Event
-        """
-
-        # Ignore changes on the status bar.  We handle them in onNameChanged.
-        #
-        if event.source.role != rolenames.ROLE_STATUSBAR:
-            default.Script.onStateChanged(self, event)
-
-    def onTextInserted(self, event):
-        """Called whenever text is inserted into an object.
-
-        Arguments:
-        - event: the Event
-        """
-
-        # Ignore changes on the status bar.  We handle them in onNameChanged.
-        #
-        if event.source.role != rolenames.ROLE_STATUSBAR:
-            default.Script.onTextInserted(self, event)
+    def presentStatusBar(self, obj):
+        """Presents information about the metacity status bar."""
 
         # We have to stop speech, as Metacity has a key grab and we're not
         # getting keys
@@ -107,26 +70,79 @@ class Script(default.Script):
                 win = app.child(i)
                 if win is None:
                     print "app error " + app.name
-                elif win.name == event.source.name:
+                elif win.name == obj.name:
                     found = True
                 i = i + 1
 
-        text = event.source.name
+        text = obj.name
 
-        # Note to translators: the "Workspace " and "Desk " strings
-        # are the prefix of what metacity shows when you press
-        # Ctrl+Alt and the left or right arrow keys to switch between
-        # workspaces.  The goal here is to find a match with that
-        # prefix.
+        # Translators: the "Workspace " and "Desk " strings are
+        # the prefix of what metacity shows when you press
+        # Ctrl+Alt and the left or right arrow keys to switch
+        # between workspaces.  The goal here is to find a match
+        # with that prefix.
         #
         if text.startswith(_("Workspace ")) or text.startswith(_("Desk ")):
             pass
         elif not found:
+            # Translators: inaccessible means that the application cannot
+            # be read by Orca.  This usually means the application is not
+            # friendly to the assistive technology infrastructure.
+            #
             text += ". " + _("inaccessible")
 
         braille.displayMessage(text)
         speech.speak(text)
 
+    def onNameChanged(self, event):
+        """The status bar in metacity tells us what toplevel window
+        will be activated when tab is released.  We will key off the
+        text inserted event to determine when to say something, as it
+        seems to be the more reliable event.
+
+        Arguments:
+        - event: the name changed Event
+        """
+
+        # Ignore changes on the status bar.  We handle them in onTextInserted.
+        #
+        if event.source.role != rolenames.ROLE_STATUSBAR:
+            default.Script.onNameChanged(self, event)
+
+    def onStateChanged(self, event):
+        """The status bar in metacity tells us what toplevel window
+        will be activated when tab is released.  We will key off the
+        text inserted event to determine when to say something, as it
+        seems to be the more reliable event.
+
+        Arguments:
+        - event: the object:state-changed: Event
+        """
+
+        # Ignore changes on the status bar.  We handle them in
+        # onTextInserted.  The only exception is if the status bar is
+        # suddenly showing.  Then, we want to present it because we
+        # typically do not get onTextInserted events at that time.
+        #
+        if event.source.role != rolenames.ROLE_STATUSBAR:
+            default.Script.onStateChanged(self, event)
+        elif (event.type.startswith("object:state-changed:showing")) \
+            and event.detail1:
+            self.presentStatusBar(event.source)
+
+    def onTextInserted(self, event):
+        """Called whenever text is inserted into an object.  This seems to
+        be the most reliable event to let us know something is changing.
+
+        Arguments:
+        - event: the Event
+        """
+
+        if event.source.role != rolenames.ROLE_STATUSBAR:
+            default.Script.onTextInserted(self, event)
+
+        self.presentStatusBar(event.source)
+
     def onTextDeleted(self, event):
         """Called whenever text is deleted from an object.
 
@@ -134,7 +150,7 @@ class Script(default.Script):
         - event: the Event
         """
 
-        # Ignore changes on the status bar.  We handle them in onNameChanged.
+        # Ignore changes on the status bar.  We handle them in onTextInserted.
         #
         if event.source.role != rolenames.ROLE_STATUSBAR:
             default.Script.onTextDeleted(self, event)
@@ -146,7 +162,7 @@ class Script(default.Script):
         - event: the Event
         """
 
-        # Ignore changes on the status bar.  We handle them in onNameChanged.
+        # Ignore changes on the status bar.  We handle them in onTextInserted.
         #
         if event.source.role != rolenames.ROLE_STATUSBAR:
             default.Script.onCaretMoved(self, event)
