@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """Custom script for planner."""
 
-__id__        = "$Id: planner.py 2141 2007-03-07 21:00:32Z richb $"
-__version__   = "$Revision: 2141 $"
-__date__      = "$Date: 2007-03-07 16:00:32 -0500 (Wed, 07 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: planner.py 2397 2007-05-16 17:01:38Z wwalker $"
+__version__   = "$Revision: 2397 $"
+__date__      = "$Date: 2007-05-16 13:01:38 -0400 (Wed, 16 May 2007) $"
+__copyright__ = "Copyright (c) 2006-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import orca.debug as debug
@@ -95,10 +95,10 @@ class BrailleGenerator(braillegenerator.BrailleGenerator):
             allLabels = self._script.findByRole(filler, rolenames.ROLE_LABEL)
             text += allLabels[0].name
 
-        if obj.state.count(atspi.Accessibility.STATE_CHECKED):
-            text = self._script.appendString(text, "&=y")
-        else:
-            text = self._script.appendString(text, "& y")
+        text = self._script.appendString(
+            settings.brailleRadioButtonIndicators[
+                obj.state.count(atspi.Accessibility.STATE_CHECKED)],
+            text)
 
         text = self._script.appendString(text, self._getTextForRole(obj))
 
