@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2581 2007-08-01 15:29:21Z richb $"
-__version__   = "$Revision: 2581 $"
-__date__      = "$Date: 2007-08-01 11:29:21 -0400 (Wed, 01 Aug 2007) $"
+__id__        = "$Id: settings.py 2828 2007-09-13 19:26:33Z wwalker $"
+__version__   = "$Revision: 2828 $"
+__date__      = "$Date: 2007-09-13 15:26:33 -0400 (Thu, 13 Sep 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -527,6 +527,12 @@ useBlockPreventor       = False
 #
 useBonoboMain           = True
 
+# If True, we handle events asynchronously - our normal mode of
+# queueing events and processing them later on the gidle thread.
+# If False, we handle events immediately - helpful for testing.
+#
+asyncMode               = True
+
 # If True, we output debug information for the event queue.  We
 # use this in addition to log level to prevent debug logic from
 # bogging down event handling.
