@@ -19,9 +19,9 @@
 
 """Speaks information about the current object of interest."""
 
-__id__        = "$Id: where_am_I.py 2961 2007-10-01 23:23:50Z joanied $"
-__version__   = "$Revision: 2961 $"
-__date__      = "$Date: 2007-10-01 19:23:50 -0400 (Mon, 01 Oct 2007) $"
+__id__        = "$Id: where_am_I.py 3025 2007-10-11 23:56:20Z joanied $"
+__version__   = "$Revision: 3025 $"
+__date__      = "$Date: 2007-10-11 19:56:20 -0400 (Thu, 11 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -47,7 +47,6 @@ class WhereAmI:
         self._script = script
         self._debugLevel = debug.LEVEL_FINEST
         self._statusBar = None
-        self._defaultButton = None
         self._lastAttributeString = ""
 
     def whereAmI(self, obj, doubleClick, orcaKey):
@@ -1129,7 +1128,7 @@ class WhereAmI:
                         if prevObj.text.getNSelections() > 0:
                             [newTextContents, start, end] = \
                                          self._getTextSelection(prevObj)
-                            textContents = newTextContents + textContents
+                            textContents = newTextContents + " " + textContents
                             current = prevObj
                             morePossibleSelections = True
                         else:
@@ -1151,7 +1150,7 @@ class WhereAmI:
                         if nextObj.text.getNSelections() > 0:
                             [newTextContents, start, end] = \
                                          self._getTextSelection(nextObj)
-                            textContents += newTextContents
+                            textContents += " " + newTextContents
                             current = nextObj
                             morePossibleSelections = True
                         else:
@@ -1413,9 +1412,7 @@ class WhereAmI:
                     self._speakStatusBar()
             window = list[1] or list[0]
             if window:
-                self._defaultButton = None
-                self._getDefaultButton(window)
-                self._speakDefaultButton()
+                self._speakDefaultButton(window)
         else:
             if list[0]:
                 text = self._getObjLabelAndName(list[0])
@@ -1503,10 +1500,8 @@ class WhereAmI:
         Arguments:
         - obj: the dialog box for which the default button should be obtained
         """
-        
-        if self._defaultButton:
-            return
 
+        defaultButton = None
         for i in range(0, obj.childCount):
             child = obj.child(i)
             # debug.println(self._debugLevel,
@@ -1514,18 +1509,25 @@ class WhereAmI:
             #               (child.role, self._getObjLabelAndName(child)))
             if child.role == rolenames.ROLE_PUSH_BUTTON \
                 and child.state.count(atspi.Accessibility.STATE_IS_DEFAULT):
-                self._defaultButton = child
-                return
+                defaultButton = child
+            else:
+                defaultButton = self._getDefaultButton(child)
 
-            if child.childCount > 0:
-                self._getDefaultButton(child)
+            if defaultButton:
+                break
 
-    def _speakDefaultButton(self):
+        return defaultButton
+
+    def _speakDefaultButton(self, obj):
         """Speaks the default button in a dialog.
+
+        Arguments:
+        - obj: the dialog box for which the default button should be obtained
         """
 
-        if not self._defaultButton \
-           or not self._defaultButton.state.count(\
+        defaultButton = self._getDefaultButton(obj)
+        if not defaultButton \
+           or not defaultButton.state.count(\
                                       atspi.Accessibility.STATE_SENSITIVE):
             return
 
@@ -1536,7 +1538,7 @@ class WhereAmI:
         # dialog box.
         #
         text = _("Default button is %s") % \
-               self._getObjName(self._defaultButton)
+               self._getObjName(defaultButton)
         utterances.append(text)
 
         debug.println(self._debugLevel, "default button utterances=%s" % \
